COLOR_SCHEMES = [
    " ",
    "picking",
    "random",
    "uniform",
    "atomindex",
    "residueindex",
    "chainindex",
    "modelindex",
    "sstruc",
    "element",
    "resname",
    "bfactor",
    "hydrophobicity",
    "value",
    "volume",
    "occupancy"]
